/**
 * @description Wrap表单配置信息
 */
export default function (config) {
  let appType = sessionStorage.getItem('appType')
  let roleList = sessionStorage.getItem('sysRoles')
  let wrap = config.wrap

  if (roleList) {
    try {
      roleList = JSON.parse(roleList)
    } catch (e) {
      roleList = []
    }
  } else {
    roleList = []
  }

  const wrapForm = [
    {
      type: 'text',
      field: 'name',
      label: '组件名称',
      initval: wrap.name || '',
      tooltip: '用于组件间的区分。',
      required: true
    },
    {
      type: 'number',
      field: 'width',
      label: '宽度',
      initval: wrap.width || 24,
      tooltip: '栅格布局，每行等分为24列。',
      min: 1,
      max: 24,
      precision: 0,
      required: true
    },
    {
      type: 'radio',
      field: 'datatype',
      label: '初始值',
      initval: wrap.datatype || 'static',
      tooltip: '初始值来源于数据源或表单默认值。',
      required: false,
      options: [
        {value: 'dynamic', label: '动态'},
        {value: 'static', label: '静态'},
      ]
    },
    {
      type: 'select',
      field: 'statusControl',
      label: '状态控制',
      initval: wrap.statusControl || '',
      tooltip: '表单加载时的状态，当字段值与表单组的状态值一致时，启用对应的表单组。',
      required: false,
      options: config.columns,
      forbid: config.subtype === 'tabform'
    },
    {
      type: 'radio',
      field: 'groupLabel',
      label: '分组名称',
      initval: wrap.groupLabel || 'show',
      tooltip: '加载时是否显示分组名称。',
      required: false,
      options: [
        {value: 'show', label: '显示'},
        {value: 'hidden', label: '隐藏'},
      ]
    },
    {
      type: 'radio',
      field: 'tabtype',
      label: '分组风格',
      initval: wrap.tabtype || 'mktab',
      required: false,
      options: [
        {value: 'mktab', label: 'tab页'},
        {value: 'mkbtn', label: '按钮组'},
      ],
      forbid: config.subtype !== 'tabform'
    },
    {
      type: 'color',
      field: 'color',
      label: '颜色控制',
      initval: wrap.color || '#1890ff',
      tooltip: '完成后的颜色',
      required: false,
      forbid: config.subtype === 'tabform'
    },
    {
      type: 'multiselect',
      field: 'blacklist',
      label: '黑名单',
      initval: wrap.blacklist || [],
      required: false,
      options: roleList,
      forbid: !!appType
    },
  ]

  return wrapForm
} 